@@ -138,11 +138,9 @@ mod tests {
   use std::fs::File;
   use std::io::prelude::*;
   use std::io::Write;
-  use tempfile::TempDir;
-
-  fn setup() -> (TempDir, PathBuf) {
-    let temp_dir = TempDir::new().expect("could not create temp dir");
+  use test_util::TempDir;
 
+  fn setup(temp_dir: &TempDir) -> PathBuf {
     let file_path = temp_dir.path().join("valid_lockfile.json");
     let mut file = File::create(file_path).expect("write file fail");
 
@@ -153,13 +151,7 @@ mod tests {
 
     file.write_all(value.to_string().as_bytes()).unwrap();
 
-    let file_path = temp_dir.path().join("valid_lockfile.json");
-
-    (temp_dir, file_path)
-  }
-
-  fn teardown(temp_dir: TempDir) {
-    temp_dir.close().expect("file close error");
+    temp_dir.path().join("valid_lockfile.json")
   }
 
   #[test]
@@ -170,7 +162,8 @@ mod tests {
 
   #[test]
   fn new_valid_lockfile() {
-    let (temp_dir, file_path) = setup();
+    let temp_dir = TempDir::new();
+    let file_path = setup(&temp_dir);
 
     let result = Lockfile::new(file_path, false).unwrap();
 
@@ -182,13 +175,12 @@ mod tests {
 
     assert_eq!(keys.len(), 2);
     assert_eq!(keys, expected_keys);
-
-    teardown(temp_dir);
   }
 
   #[test]
   fn new_lockfile_from_file_and_insert() {
-    let (temp_dir, file_path) = setup();
+    let temp_dir = TempDir::new();
+    let file_path = setup(&temp_dir);
 
     let mut lockfile = Lockfile::new(file_path, false).unwrap();
 
@@ -205,13 +197,12 @@ mod tests {
     ];
     assert_eq!(keys.len(), 3);
     assert_eq!(keys, expected_keys);
-
-    teardown(temp_dir);
   }
 
   #[test]
   fn new_lockfile_and_write() {
-    let (temp_dir, file_path) = setup();
+    let temp_dir = TempDir::new();
+    let file_path = setup(&temp_dir);
 
     let mut lockfile = Lockfile::new(file_path, true).unwrap();
 
@@ -264,13 +255,12 @@ mod tests {
       Some("https://deno.land/std@0.71.0/textproto/mod.ts")
     );
     assert!(keys.next().is_none());
-
-    teardown(temp_dir);
   }
 
   #[test]
   fn check_or_insert_lockfile_false() {
-    let (temp_dir, file_path) = setup();
+    let temp_dir = TempDir::new();
+    let file_path = setup(&temp_dir);
 
     let mut lockfile = Lockfile::new(file_path, false).unwrap();
 
@@ -290,7 +280,5 @@ mod tests {
       "This is new Source code",
     );
     assert!(!check_false);
-
-    teardown(temp_dir);
   }
 }
