@@ -1,4 +1,4 @@
-// Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
+// Copyright 2018-2022 the Deno authors. All rights reserved. MIT license.
 
 // The logic of this module is heavily influenced by path-to-regexp at:
 // https://github.com/pillarjs/path-to-regexp/ which is licensed as follows:
@@ -249,7 +249,11 @@ impl StringOrVec {
     }
   }
 
-  pub fn to_string(&self, maybe_key: Option<&Key>) -> String {
+  pub fn to_string(
+    &self,
+    maybe_key: Option<&Key>,
+    omit_initial_prefix: bool,
+  ) -> String {
     match self {
       Self::String(s) => s.clone(),
       Self::Vec(v) => {
@@ -262,8 +266,12 @@ impl StringOrVec {
           ("/".to_string(), "".to_string())
         };
         let mut s = String::new();
-        for segment in v {
-          s.push_str(&format!("{}{}{}", prefix, segment, suffix));
+        for (i, segment) in v.iter().enumerate() {
+          if omit_initial_prefix && i == 0 {
+            s.push_str(&format!("{}{}", segment, suffix));
+          } else {
+            s.push_str(&format!("{}{}{}", prefix, segment, suffix));
+          }
         }
         s
       }
@@ -733,7 +741,7 @@ impl Compiler {
                 let prefix = k.prefix.clone().unwrap_or_default();
                 let suffix = k.suffix.clone().unwrap_or_default();
                 for segment in v {
-                  if self.validate {
+                  if !segment.is_empty() && self.validate {
                     if let Some(re) = &self.matches[i] {
                       if !re.is_match(segment) {
                         return Err(anyhow!(
@@ -911,6 +919,33 @@ mod tests {
     assert_eq!(actual, "/x/y@v1.0.0/z/example.ts".to_string());
   }
 
+  #[test]
+  fn test_compiler_ends_with_sep() {
+    let tokens = parse("/x/:a@:b/:c*", None).expect("could not parse");
+    let mut params = HashMap::<StringOrNumber, StringOrVec>::new();
+    params.insert(
+      StringOrNumber::String("a".to_string()),
+      StringOrVec::String("y".to_string()),
+    );
+    params.insert(
+      StringOrNumber::String("b".to_string()),
+      StringOrVec::String("v1.0.0".to_string()),
+    );
+    params.insert(
+      StringOrNumber::String("c".to_string()),
+      StringOrVec::Vec(vec![
+        "z".to_string(),
+        "example".to_string(),
+        "".to_string(),
+      ]),
+    );
+    let compiler = Compiler::new(&tokens, None);
+    let actual = compiler.to_path(&params);
+    assert!(actual.is_ok());
+    let actual = actual.unwrap();
+    assert_eq!(actual, "/x/y@v1.0.0/z/example/".to_string());
+  }
+
   #[test]
   fn test_string_to_regex() {
     test_path("/", None, &[("/test", None), ("/", Some(("/", 0, 1)))]);
