@@ -31,12 +31,12 @@ use deno_graph::Dependency;
 use deno_runtime::deno_web::BlobStore;
 use deno_runtime::permissions::Permissions;
 use log::error;
-use lspower::lsp;
 use once_cell::sync::Lazy;
 use regex::Regex;
 use std::collections::HashMap;
 use std::path::Path;
 use std::path::PathBuf;
+use tower_lsp::lsp_types as lsp;
 
 const CONFIG_PATH: &str = "/.well-known/deno-import-intellisense.json";
 const COMPONENT: &percent_encoding::AsciiSet = &percent_encoding::CONTROLS
@@ -1050,7 +1050,7 @@ impl ModuleRegistry {
 #[cfg(test)]
 mod tests {
   use super::*;
-  use tempfile::TempDir;
+  use test_util::TempDir;
 
   #[test]
   fn test_validate_registry_configuration() {
@@ -1205,7 +1205,7 @@ mod tests {
   #[tokio::test]
   async fn test_registry_completions_origin_match() {
     let _g = test_util::http_server();
-    let temp_dir = TempDir::new().expect("could not create tmp");
+    let temp_dir = TempDir::new();
     let location = temp_dir.path().join("registries");
     let mut module_registry =
       ModuleRegistry::new(&location, ModuleRegistryOptions::default()).unwrap();
@@ -1266,7 +1266,7 @@ mod tests {
   #[tokio::test]
   async fn test_registry_completions() {
     let _g = test_util::http_server();
-    let temp_dir = TempDir::new().expect("could not create tmp");
+    let temp_dir = TempDir::new();
     let location = temp_dir.path().join("registries");
     let mut module_registry =
       ModuleRegistry::new(&location, ModuleRegistryOptions::default()).unwrap();
@@ -1489,7 +1489,7 @@ mod tests {
   #[tokio::test]
   async fn test_registry_completions_key_first() {
     let _g = test_util::http_server();
-    let temp_dir = TempDir::new().expect("could not create tmp");
+    let temp_dir = TempDir::new();
     let location = temp_dir.path().join("registries");
     let mut module_registry =
       ModuleRegistry::new(&location, ModuleRegistryOptions::default()).unwrap();
@@ -1559,7 +1559,7 @@ mod tests {
   #[tokio::test]
   async fn test_registry_completions_complex() {
     let _g = test_util::http_server();
-    let temp_dir = TempDir::new().expect("could not create tmp");
+    let temp_dir = TempDir::new();
     let location = temp_dir.path().join("registries");
     let mut module_registry =
       ModuleRegistry::new(&location, ModuleRegistryOptions::default()).unwrap();
@@ -1610,7 +1610,7 @@ mod tests {
   #[tokio::test]
   async fn test_check_origin_supported() {
     let _g = test_util::http_server();
-    let temp_dir = TempDir::new().expect("could not create tmp");
+    let temp_dir = TempDir::new();
     let location = temp_dir.path().join("registries");
     let module_registry =
       ModuleRegistry::new(&location, ModuleRegistryOptions::default()).unwrap();
@@ -1621,7 +1621,7 @@ mod tests {
   #[tokio::test]
   async fn test_check_origin_not_supported() {
     let _g = test_util::http_server();
-    let temp_dir = TempDir::new().expect("could not create tmp");
+    let temp_dir = TempDir::new();
     let location = temp_dir.path().join("registries");
     let module_registry =
       ModuleRegistry::new(&location, ModuleRegistryOptions::default()).unwrap();
