@@ -1,7 +1,6 @@
 // Copyright 2018-2022 the Deno authors. All rights reserved. MIT license.
 
 use crate::diagnostics::Diagnostics;
-use crate::fmt_errors::format_file_name;
 use deno_core::error::AnyError;
 use deno_core::op;
 use deno_core::serde_json;
@@ -11,10 +10,7 @@ use deno_core::Extension;
 
 pub fn init() -> Extension {
   Extension::builder()
-    .ops(vec![
-      op_format_diagnostic::decl(),
-      op_format_file_name::decl(),
-    ])
+    .ops(vec![op_format_diagnostic::decl()])
     .build()
 }
 
@@ -23,8 +19,3 @@ fn op_format_diagnostic(args: Value) -> Result<Value, AnyError> {
   let diagnostic: Diagnostics = serde_json::from_value(args)?;
   Ok(json!(diagnostic.to_string()))
 }
-
-#[op]
-fn op_format_file_name(file_name: String) -> Result<String, AnyError> {
-  Ok(format_file_name(&file_name))
-}
