@@ -817,7 +817,6 @@ async fn test_resolve_dns() {
   use std::net::SocketAddr;
   use std::str::FromStr;
   use std::sync::Arc;
-  use std::sync::RwLock;
   use std::time::Duration;
   use tokio::net::TcpListener;
   use tokio::net::UdpSocket;
@@ -951,7 +950,7 @@ async fn test_resolve_dns() {
         map
       };
 
-      let authority = Box::new(Arc::new(RwLock::new(
+      let authority = Box::new(Arc::new(
         InMemoryAuthority::new(
           Name::from_str("com").unwrap(),
           records,
@@ -959,7 +958,7 @@ async fn test_resolve_dns() {
           false,
         )
         .unwrap(),
-      )));
+      ));
       let mut c = Catalog::new();
       c.upsert(Name::root().into(), authority);
       c
