@@ -206,6 +206,20 @@ fn pty_assign_global_this() {
   });
 }
 
+#[test]
+fn pty_emoji() {
+  // windows was having issues displaying this
+  util::with_pty(&["repl"], |mut console| {
+    console.write_line("console.log('🦕');");
+    console.write_line("close();");
+
+    let output = console.read_all_output();
+    // one for input, one for output
+    let emoji_count = output.chars().filter(|c| *c == '🦕').count();
+    assert_eq!(emoji_count, 2);
+  });
+}
+
 #[test]
 fn console_log() {
   let (out, err) = util::run_and_collect_output(
