@@ -1,4 +1,4 @@
 Deno.test("no-op", function () {});
 Deno.test("leak interval", function () {
-  setInterval(function () {});
+  setInterval(function () {}, 100000);
 });
