@@ -468,46 +468,6 @@ Deno.test(
   },
 );
 
-Deno.test(
-  { permissions: { run: true, read: true } },
-  async function spawnOverrideStdio() {
-    const { stdout, stderr } = await Deno.spawn(Deno.execPath(), {
-      args: [
-        "eval",
-        "console.log('hello'); console.error('world')",
-      ],
-      stdin: "piped",
-      stdout: "null",
-      stderr: "null",
-    });
-
-    // @ts-ignore: for testing
-    assertEquals(new TextDecoder().decode(stdout), "hello\n");
-    // @ts-ignore: for testing
-    assertEquals(new TextDecoder().decode(stderr), "world\n");
-  },
-);
-
-Deno.test(
-  { permissions: { run: true, read: true } },
-  function spawnSyncOverrideStdio() {
-    const { stdout, stderr } = Deno.spawnSync(Deno.execPath(), {
-      args: [
-        "eval",
-        "console.log('hello'); console.error('world')",
-      ],
-      stdin: "piped",
-      stdout: "null",
-      stderr: "null",
-    });
-
-    // @ts-ignore: for testing
-    assertEquals(new TextDecoder().decode(stdout), "hello\n");
-    // @ts-ignore: for testing
-    assertEquals(new TextDecoder().decode(stderr), "world\n");
-  },
-);
-
 Deno.test(
   { permissions: { run: true, read: true } },
   async function spawnEnv() {
@@ -685,3 +645,25 @@ Deno.test(
     }
   },
 );
+
+Deno.test(async function spawnStdinPipedFails() {
+  await assertRejects(
+    () =>
+      Deno.spawn("id", {
+        stdin: "piped",
+      }),
+    TypeError,
+    "Piped stdin is not supported for this function, use 'Deno.spawnChild()' instead",
+  );
+});
+
+Deno.test(function spawnSyncStdinPipedFails() {
+  assertThrows(
+    () =>
+      Deno.spawnSync("id", {
+        stdin: "piped",
+      }),
+    TypeError,
+    "Piped stdin is not supported for this function, use 'Deno.spawnChild()' instead",
+  );
+});
