@@ -4,17 +4,17 @@ import {
   assertRejects,
   assertThrows,
   pathToAbsoluteFileUrl,
-  unitTest,
+  unreachable,
 } from "./test_util.ts";
 
-unitTest({ permissions: { read: true } }, function readTextFileSyncSuccess() {
+Deno.test({ permissions: { read: true } }, function readTextFileSyncSuccess() {
   const data = Deno.readTextFileSync("cli/tests/testdata/fixture.json");
   assert(data.length > 0);
   const pkg = JSON.parse(data);
   assertEquals(pkg.name, "deno");
 });
 
-unitTest({ permissions: { read: true } }, function readTextFileSyncByUrl() {
+Deno.test({ permissions: { read: true } }, function readTextFileSyncByUrl() {
   const data = Deno.readTextFileSync(
     pathToAbsoluteFileUrl("cli/tests/testdata/fixture.json"),
   );
@@ -23,19 +23,19 @@ unitTest({ permissions: { read: true } }, function readTextFileSyncByUrl() {
   assertEquals(pkg.name, "deno");
 });
 
-unitTest({ permissions: { read: false } }, function readTextFileSyncPerm() {
+Deno.test({ permissions: { read: false } }, function readTextFileSyncPerm() {
   assertThrows(() => {
     Deno.readTextFileSync("cli/tests/testdata/fixture.json");
   }, Deno.errors.PermissionDenied);
 });
 
-unitTest({ permissions: { read: true } }, function readTextFileSyncNotFound() {
+Deno.test({ permissions: { read: true } }, function readTextFileSyncNotFound() {
   assertThrows(() => {
     Deno.readTextFileSync("bad_filename");
   }, Deno.errors.NotFound);
 });
 
-unitTest(
+Deno.test(
   { permissions: { read: true } },
   async function readTextFileSuccess() {
     const data = await Deno.readTextFile("cli/tests/testdata/fixture.json");
@@ -45,7 +45,7 @@ unitTest(
   },
 );
 
-unitTest({ permissions: { read: true } }, async function readTextFileByUrl() {
+Deno.test({ permissions: { read: true } }, async function readTextFileByUrl() {
   const data = await Deno.readTextFile(
     pathToAbsoluteFileUrl("cli/tests/testdata/fixture.json"),
   );
@@ -54,19 +54,19 @@ unitTest({ permissions: { read: true } }, async function readTextFileByUrl() {
   assertEquals(pkg.name, "deno");
 });
 
-unitTest({ permissions: { read: false } }, async function readTextFilePerm() {
+Deno.test({ permissions: { read: false } }, async function readTextFilePerm() {
   await assertRejects(async () => {
     await Deno.readTextFile("cli/tests/testdata/fixture.json");
   }, Deno.errors.PermissionDenied);
 });
 
-unitTest({ permissions: { read: true } }, function readTextFileSyncLoop() {
+Deno.test({ permissions: { read: true } }, function readTextFileSyncLoop() {
   for (let i = 0; i < 256; i++) {
     Deno.readTextFileSync("cli/tests/testdata/fixture.json");
   }
 });
 
-unitTest(
+Deno.test(
   { permissions: { read: true } },
   async function readTextFileDoesNotLeakResources() {
     const resourcesBefore = Deno.resources();
@@ -75,7 +75,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true } },
   function readTextFileSyncDoesNotLeakResources() {
     const resourcesBefore = Deno.resources();
@@ -84,20 +84,61 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true } },
   async function readTextFileWithAbortSignal() {
     const ac = new AbortController();
     queueMicrotask(() => ac.abort());
-    await assertRejects(async () => {
-      await Deno.readFile("cli/tests/testdata/fixture.json", {
-        signal: ac.signal,
-      });
-    });
+    await assertRejects(
+      async () => {
+        await Deno.readFile("cli/tests/testdata/fixture.json", {
+          signal: ac.signal,
+        });
+      },
+      (error: Error) => {
+        assert(error instanceof DOMException);
+        assertEquals(error.name, "AbortError");
+      },
+    );
   },
 );
 
-unitTest(
+Deno.test(
+  { permissions: { read: true } },
+  async function readTextFileWithAbortSignalReason() {
+    const ac = new AbortController();
+    const abortReason = new Error();
+    queueMicrotask(() => ac.abort(abortReason));
+    await assertRejects(
+      async () => {
+        await Deno.readFile("cli/tests/testdata/fixture.json", {
+          signal: ac.signal,
+        });
+      },
+      (error: Error) => {
+        assertEquals(error, abortReason);
+      },
+    );
+  },
+);
+
+Deno.test(
+  { permissions: { read: true } },
+  async function readTextFileWithAbortSignalPrimitiveReason() {
+    const ac = new AbortController();
+    queueMicrotask(() => ac.abort("Some string"));
+    try {
+      await Deno.readFile("cli/tests/testdata/fixture.json", {
+        signal: ac.signal,
+      });
+      unreachable();
+    } catch (e) {
+      assertEquals(e, "Some string");
+    }
+  },
+);
+
+Deno.test(
   { permissions: { read: true }, ignore: Deno.build.os !== "linux" },
   async function readTextFileProcFs() {
     const data = await Deno.readTextFile("/proc/self/stat");
