@@ -315,7 +315,7 @@ impl Highlighter for EditorHelper {
               colors::green(&line[span]).to_string()
             }
             Token::Regex(_, _) => colors::red(&line[span]).to_string(),
-            Token::Num(_) | Token::BigInt(_) => {
+            Token::Num { .. } | Token::BigInt { .. } => {
               colors::yellow(&line[span]).to_string()
             }
             Token::Word(word) => match word {
